@@ -112,6 +112,13 @@ If nil, never time out."
                  (const  :tag "Never time out" nil))
   :group 'eask)
 
+;; This is used to avoid the error:
+;;
+;;   Ignoring unknown mode `eask-mode'.
+;;
+(unless (fboundp 'eask-mode)
+  (define-derived-mode eask-mode emacs-lisp-mode "Eask"))
+
 ;;
 ;;; Execution
 
@@ -157,7 +164,8 @@ will return `lint/checkdoc' with a dash between two subcommands."
   "Report error if the current command requires minimum VERSION."
   (when (version< emacs-version version)
     (eask-error "The command `%s' requires Emacs %s and above!"
-                (eask-command) version)))
+                (eask-s-replace "/" " " (eask-command))  ; Pretty print.
+                version)))
 
 (defun eask-command-p (commands)
   "Return t if COMMANDS is the current command."
